# pyliff
A CLI tool for LIFF(LINE Frontend Framework), it is inspired by https://github.com/plateaukao/pylineliff.

The original API documents is here
https://developers.line.me/en/docs/liff/overview/ 

## Installation
```pip install pyliff```

## Basic Usage

#### Add new access token
```liff token add <name> <token>```

#### Create new LIFF application
```liff create <url> <type>[compact, tall, full]```

#### List all LIFF applications
```liff list```

#### Show help
```liff```